@@ -529,11 +529,11 @@ QScrollArea *MainWindow::createScrollArea(QWidget *parent, RemoteView *remoteVie
     connect(scrollArea, SIGNAL(resized(int,int)), remoteView, SLOT(scaleResize(int,int)));
 
     QPalette palette = scrollArea->palette();
-    palette.setColor(QPalette::Active, QPalette::Background, Settings::backgroundColor());
+    palette.setColor(QPalette::Background, Settings::backgroundColor());
     scrollArea->setPalette(palette);
 
     scrollArea->setFrameStyle(QFrame::NoFrame);
-    scrollArea->viewport()->setAutoFillBackground(true);
+    scrollArea->setAutoFillBackground(true);
     scrollArea->setWidget(remoteView);
 
     return scrollArea;
